import { Subject } from 'rxjs/Subject';
import '../../../rxjs-operators';
import { ToolsService } from '@core/services/tools.service';
import { Component, OnInit } from '@angular/core';
import { NzMessageService } from 'ng-zorro-antd';
import { ModalHelper } from '@delon/theme';
import { HttpClient } from '@angular/common/http';
import { environment } from '../../../../environments/environment';
import { DateService } from '@core/services/date.service';
import { VersionService } from 'app/routes/devices/version/version.service';
import { Types } from '@core/enum/types.enum';
import { Column, Grid, PageBean } from '@core/entity/grid';

interface DeviceVersion {
  createTime: Column;
  description: Column;
  id?: Column;
  name: Column;
  version: Column;
}
@Component({
  selector: 'app-version',
  templateUrl: './version.component.html',
  styles: []
})
export class VersionComponent implements OnInit {

  grid: Grid = new Grid(null);
  queryMap = { text: '请输入名称或型号', value: ''};
  queryTextStream: Subject<string> = new Subject<string>();
    private initPage() {
    const columns: DeviceVersion = {
       name: {
        text: '名称',
        width: '22%'
       },
       version: {
        text: '型号',
        width: '22%'
      },
      createTime: {
          text: '创建时间',
          width: '22%',
          type: {
            name: Types.Date,
            format: 'YYYY-MM-DD HH:mm:ss'
          }
      },
      description: {
          text: '备注',
          width: '22%'
      }
    };
    this.grid.title = '设备型号';
    this.grid.setColumns(columns);
    this.grid.pageSize = 10;
  }
  constructor(
    public http: HttpClient,
    private versionService: VersionService,
    public dateSrv: DateService,
    public msgSrv: NzMessageService,
    private modalHelper: ModalHelper,
    private toolsService: ToolsService) {}

  ngOnInit() {
    this.initPage();
    this.queryTextStream
    .debounceTime(1000)
    .distinctUntilChanged()
    .subscribe(queryText => {
        this.load();
    });
  }
  queryTextChanged($event) {
      // tslint:disable-next-line:no-debugger
      debugger;
      this.queryTextStream.next(this.queryText);
  }
  load(reload: boolean = false) {
    if (reload) {
      this.grid.pageIndex = 1 ;
    }
    this.versionService.getPagingList(this.grid, this.queryText).subscribe(
       (res: PageBean) => {
            if (res.total > 0 && res.data != null) {
              this.grid.initData(res);
              this.grid.refreshStatus();
            }
       }
    );
  }

  edit() {
    // this.modalHelper.static(VersionEditComponent, { user }).subscribe(() => {
    //   this.load(true);
    //   this.msgSrv.success('安装用户修改成功！');
    // });
  }

  add() {
    // const user = {};
    // this.modalHelper.static(VersionEditComponent, { user }).subscribe(() => {
    //   this.load(true);
    //   this.msgSrv.success('安装用户保存成功！');
    // });
  }

  delete(user) {
    this.http.delete(environment.SERVER_BASH_URL + '/user/operate_user/' + user.id).subscribe((res: any) => {
      this.msgSrv.success('安装用户删除成功！');
      this.load(true);
    });
  }

  remove() {

  }


  dataChange(res: any) {

  }

  sort(field: string, value: any) {
    // this.sortMap = {};
    // this.sortMap[field] = value;
    // this.q.sorter = value ? `${field}_${value}` : '';
    // this.load(true);
  }

  reset(ls: any[]) {
    for (const item of ls) item.value = false;
    this.load(true);
  }

}
